import * as pulumi from "@pulumi/pulumi";
import * as pulumiAws from "@pulumi/aws";
/**
 * NodeGroupSecurityGroup is a component that wraps creating a security group for node groups with the default ingress & egress rules required to connect and work with the EKS cluster security group.
 */
export declare class NodeGroupSecurityGroup extends pulumi.ComponentResource {
    /**
     * Returns true if the given object is an instance of NodeGroupSecurityGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is NodeGroupSecurityGroup;
    /**
     * The security group for node groups with the default ingress & egress rules required to connect and work with the EKS cluster security group.
     */
    readonly securityGroup: pulumi.Output<pulumiAws.ec2.SecurityGroup>;
    /**
     * The EKS cluster ingress rule.
     */
    readonly securityGroupRule: pulumi.Output<pulumiAws.ec2.SecurityGroupRule>;
    /**
     * Create a NodeGroupSecurityGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: NodeGroupSecurityGroupArgs, opts?: pulumi.ComponentResourceOptions);
}
/**
 * The set of arguments for constructing a NodeGroupSecurityGroup resource.
 */
export interface NodeGroupSecurityGroupArgs {
    /**
     * The security group associated with the EKS cluster.
     */
    clusterSecurityGroup: pulumi.Input<pulumiAws.ec2.SecurityGroup>;
    /**
     * The EKS cluster associated with the worker node group
     */
    eksCluster: pulumi.Input<pulumiAws.eks.Cluster>;
    /**
     * Key-value mapping of tags to apply to this security group.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The VPC in which to create the worker node group.
     */
    vpcId: pulumi.Input<string>;
}
